@@ -9,11 +9,11 @@ Test::Valgrind::Parser::Text - Parse valgrind output as a text stream.
 
 =head1 VERSION
 
-Version 1.11
+Version 1.15
 
 =cut
 
-our $VERSION = '1.11';
+our $VERSION = '1.15';
 
 =head1 DESCRIPTION
 
@@ -21,11 +21,13 @@ This is a L<Test::Valgrind::Parser> object that can extract suppressions from C<
 
 =cut
 
-use base qw/Test::Valgrind::Parser/;
+use base qw<Test::Valgrind::Parser>;
 
 =head1 METHODS
 
-=head2 C<args $session, $fh>
+=head2 C<args>
+
+    my @args = $tvp->args($session, $fh);
 
 Returns the arguments needed to tell C<valgrind> to print in text to the filehandle C<$fh>.
 
@@ -64,7 +66,7 @@ You can find documentation for this module with the perldoc command.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2009 Vincent Pit, all rights reserved.
+Copyright 2009,2010,2011,2013,2015 Vincent Pit, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
